(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     46380,       1444]
NotebookOptionsPosition[     41976,       1287]
NotebookOutlinePosition[     42578,       1310]
CellTagsIndexPosition[     42491,       1305]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.450336910857295*^9, 3.450336917940371*^9}, {
  3.5689025000773764`*^9, 3.56890250678376*^9}}],

Cell[BoxData[
 TagBox[
  FrameBox["\<\"SpinDynamica version 3.0.1 loaded\"\>"],
  DisplayForm]], "Print",
 CellChangeTimes->{3.712160616041072*^9}],

Cell[BoxData[
 TemplateBox[{
  "ModifyBuiltIn","report",
   "\"The following built-in routines have been modified in SpinDynamica: \\!\
\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"Chop\\\", \\\",\\\", \\\"Dot\\\", \
\\\",\\\", \\\"Duration\\\", \\\",\\\", \\\"Exp\\\", \\\",\\\", \
\\\"Expand\\\", \\\",\\\", \\\"ExpandAll\\\", \\\",\\\", \\\"NumericQ\\\", \\\
\",\\\", \\\"Plus\\\", \\\",\\\", \\\"Power\\\", \\\",\\\", \\\"Simplify\\\", \
\\\",\\\", \\\"Times\\\", \\\",\\\", \\\"WignerD\\\"}], \\\"}\\\"}]\\). \
\\nEvaluate \
??\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\) to \
generate the additional definitions for \
\\!\\(\\*\\nStyleBox[\\\"symbol\\\",\\nFontSlant->\\\"Italic\\\"]\\).\"",2,1,
   1,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7121606172003937`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["spherical tensor operators", "Section",
 CellChangeTimes->{{3.409835932148664*^9, 3.4098359332319307`*^9}, {
   3.4098390176396713`*^9, 3.4098390405388737`*^9}, 3.434352335107329*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "opT"}]], "Input",
 CellChangeTimes->{{3.50294669379099*^9, 3.502946697298884*^9}}],

Cell[BoxData[
 StyleBox["\<\"opT[j,{1,\[Mu]}] defines a first-rank spherical tensor \
operator for spin j.\\nopT[{1,\[Mu]}] defaults to \
opT[1,{1,\[Mu]}].\\nopT[{j,k},{2,\[Mu]}] defines a second-rank spherical \
tensor operator for spins j and k.\\nopT[2,\[Mu]] defaults to opT[{1,2},{2,\
\[Mu]}]\\nopT[{{j,\!\(\*SubscriptBox[\(\[Lambda]\), \
\(j\)]\)},{k,\!\(\*SubscriptBox[\(\[Lambda]\), \
\(k\)]\)}..},{\[CapitalLambda],M}] generates a \[CapitalLambda]th rank ISTO \
by coupling together the interactions {{j,\!\(\*SubscriptBox[\(\[Lambda]\), \
\(j\)]\)},{k,\!\(\*SubscriptBox[\(\[Lambda]\), \(k\)]\)}..} where j is a \
symbol identifying the interaction and \!\(\*SubscriptBox[\(\[Lambda]\), \
\(j\)]\) is its rank.\\nopT[{j,k..},{\[CapitalLambda],M}] defaults to \
opT[{{j,1},{k,1}..},{\[CapitalLambda],M}].\\nThe option Normalize->True may \
be set to generate STOs normalized in the current state basis.\\nIn cases \
where there are many possible coupling paths to the requested operator, a \
message is issued and a list of all possible operators is returned. A single \
operator may be returned using the form \
opT[{{j,\!\(\*SubscriptBox[\(\[Lambda]\), \(j\)]\)},{k,\!\(\*SubscriptBox[\(\
\[Lambda]\), \(k\)]\)}..},{\[CapitalLambda],M},n], where n is an integer \
identifying the requested operator. \\nAn explicit coupling pathway may also \
be specified. For example, a rank-2 operator generated by coupling together \
the rank-1 operator for spin #1 with the rank-1 operator for spin #2, and \
then coupling the resulting rank-1 operator with a rank-2 operator for spin \
#3, may be specified as follows: opT[{{{{1,1},{2,1}},1},{3,2}},{2,M}].\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.7121606175593605`*^9},
 CellTags->"Info23712164217-9518567"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["single spin-1/2", "Section",
 CellChangeTimes->{{3.435164762785845*^9, 3.435164768887135*^9}, {
  3.502946734466859*^9, 3.502946742555179*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.502946700828945*^9, 3.502946705267305*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}], \\\"}\\\"}]\\)\"",2,3,2,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.515083910299376*^9, 3.5689025145342035`*^9, 
   3.7121606175838785`*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \
\\\"Automatic\\\"}]}], \\\"]\\\"}]\\).\"",2,3,3,29119468785498852949,"Local"},
  
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.515083910299376*^9, 3.5689025145342035`*^9, 
   3.712160617632412*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.4098391240722437`*^9, 3.430625834584798*^9, 3.4306259637541933`*^9, 
   3.433526846328837*^9, 3.434352338245452*^9, 3.4343534334974117`*^9, 
   3.434353654764881*^9, 3.435164192975973*^9, {3.435164384310895*^9, 
   3.435164398581028*^9}, 3.435164535042913*^9, 3.43516477717758*^9, 
   3.435215747675273*^9, 3.438941567505869*^9, 3.4395535943058243`*^9, {
   3.448348268810351*^9, 3.448348272961355*^9}, 3.448350444269628*^9, 
   3.448350740645598*^9, 3.448362897212866*^9, 3.449299213273988*^9, 
   3.450336458518717*^9, 3.456163219839057*^9, 3.461037069719376*^9, 
   3.461064824085437*^9, 3.4610649590948963`*^9, 3.462799036421393*^9, {
   3.502946678974873*^9, 3.502946708625627*^9}, 3.515083910335751*^9, 
   3.5689025147882175`*^9, 3.71216061764242*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData["\<\"\[DoubleStruckCapitalO]\"\>"], "Output",
 CellChangeTimes->{
  3.409839125650468*^9, 3.430625834863289*^9, 3.430625963801936*^9, 
   3.433526846612516*^9, 3.434352338509614*^9, 3.434353433810924*^9, 
   3.434353655084776*^9, 3.435164193242364*^9, {3.4351643843691587`*^9, 
   3.435164398630395*^9}, 3.435164535310061*^9, 3.435164777224841*^9, 
   3.435215747947064*^9, 3.4389415677769957`*^9, 3.439553594593837*^9, {
   3.44834826899916*^9, 3.448348273062286*^9}, 3.4483504443271217`*^9, 
   3.448350740719461*^9, 3.448362897265768*^9, 3.4492992133239202`*^9, 
   3.450336458586773*^9, 3.456163219891069*^9, 3.461037069780645*^9, 
   3.4610648241465054`*^9, 3.461064959143571*^9, 3.462799036503488*^9, 
   3.502946679057289*^9, 3.502946710653652*^9, 3.5150839103930197`*^9, 
   3.5689025150632334`*^9, 3.7121606176529264`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946715304886*^9, 3.5029467199394503`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   TagBox[
    SubsuperscriptBox["I", "1", "+"],
    DisplayForm], 
   SqrtBox["2"]]}]], "Output",
 CellChangeTimes->{3.502946720395687*^9, 3.515083910431078*^9, 
  3.5689025151162367`*^9, 3.712160617664435*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5029467237761307`*^9, 3.5029467280933*^9}}],

Cell[BoxData[
 FractionBox[
  TagBox[
   SubsuperscriptBox["I", "1", "-"],
   DisplayForm], 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{3.502946728498217*^9, 3.515083910517061*^9, 
  3.5689025151562386`*^9, 3.712160617678445*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["single spin-3/2", "Section",
 CellChangeTimes->{{3.435164762785845*^9, 3.435164768887135*^9}, {
  3.502946734466859*^9, 3.502946751907659*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"3", "/", "2"}]}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.502946700828945*^9, 3.502946705267305*^9}, {
  3.502946753971287*^9, 3.502946756838216*^9}}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"3\\\", \\\"2\
\\\"]}], \\\"}\\\"}], \\\"}\\\"}]\\)\"",2,8,4,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.502946758667232*^9, 3.515083910564189*^9, 
   3.568902515418254*^9, 3.712160617694457*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \
\\\",\\\", FractionBox[\\\"3\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\"}\\\"}], \
\\\",\\\", RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \
\\\"Automatic\\\"}]}], \\\"]\\\"}]\\).\"",2,8,5,29119468785498852949,"Local"},
  
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.502946758667232*^9, 3.515083910564189*^9, 
   3.568902515418254*^9, 3.7121606177140646`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.4098391240722437`*^9, 3.430625834584798*^9, 3.4306259637541933`*^9, 
   3.433526846328837*^9, 3.434352338245452*^9, 3.4343534334974117`*^9, 
   3.434353654764881*^9, 3.435164192975973*^9, {3.435164384310895*^9, 
   3.435164398581028*^9}, 3.435164535042913*^9, 3.43516477717758*^9, 
   3.435215747675273*^9, 3.438941567505869*^9, 3.4395535943058243`*^9, {
   3.448348268810351*^9, 3.448348272961355*^9}, 3.448350444269628*^9, 
   3.448350740645598*^9, 3.448362897212866*^9, 3.449299213273988*^9, 
   3.450336458518717*^9, 3.456163219839057*^9, 3.461037069719376*^9, 
   3.461064824085437*^9, 3.4610649590948963`*^9, 3.462799036421393*^9, {
   3.502946678974873*^9, 3.502946708625627*^9}, 3.502946761328019*^9, 
   3.515083910649145*^9, 3.5689025156642675`*^9, 3.712160617743085*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "x"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "x"}]],
        DisplayForm]}],
      DisplayForm], ")"}]}], "-", 
   TagBox[
    RowBox[{
     TagBox[
      SubscriptBox["I", 
       RowBox[{"1", "y"}]],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubscriptBox["I", 
       RowBox[{"1", "y"}]],
      DisplayForm]}],
    DisplayForm], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm]}],
      DisplayForm], ")"}]}]}], 
  SqrtBox["6"]]], "Output",
 CellChangeTimes->{
  3.409839125650468*^9, 3.430625834863289*^9, 3.430625963801936*^9, 
   3.433526846612516*^9, 3.434352338509614*^9, 3.434353433810924*^9, 
   3.434353655084776*^9, 3.435164193242364*^9, {3.4351643843691587`*^9, 
   3.435164398630395*^9}, 3.435164535310061*^9, 3.435164777224841*^9, 
   3.435215747947064*^9, 3.4389415677769957`*^9, 3.439553594593837*^9, {
   3.44834826899916*^9, 3.448348273062286*^9}, 3.4483504443271217`*^9, 
   3.448350740719461*^9, 3.448362897265768*^9, 3.4492992133239202`*^9, 
   3.450336458586773*^9, 3.456163219891069*^9, 3.461037069780645*^9, 
   3.4610648241465054`*^9, 3.461064959143571*^9, 3.462799036503488*^9, 
   3.502946679057289*^9, 3.502946710653652*^9, 3.5029467658651333`*^9, 
   3.515083910765525*^9, 3.568902515809276*^9, 3.7121606178916907`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946778324418*^9, 3.502946778451035*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   TagBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox["I", "1", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "1", "+"],
      DisplayForm]}],
    DisplayForm], ")"}]}]], "Output",
 CellChangeTimes->{3.502946778938848*^9, 3.515083910816579*^9, 
  3.5689025158492785`*^9, 3.7121606179112062`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946786316326*^9, 3.502946788075032*^9}}],

Cell[BoxData[
 TemplateBox[{
  "opT","high\[Lambda]",
   "\"Spherical tensor operators of high rank are calculated using the \
Wigner-Eckart theorem and provided in the form of Operator. Explicit \
expressions may be constructed by applying ExpressOperator. This message \
appears only once.\"",2,12,6,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.712160617931719*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"Operator", "[", 
    RowBox[{
     RowBox[{"<<", ".."}], ">>"}]}], 
   RowBox[{",", " ", 
    RowBox[{"OperatorType", "\[Rule]", "\<\"Hermitian\"\>"}]}], " ", "]"}],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5029467886821003`*^9, 3.515083910895582*^9, 
  3.5689025159792857`*^9, 3.712160617957738*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946786316326*^9, 3.502946803540596*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"Operator", "[", 
    RowBox[{
     RowBox[{"<<", ".."}], ">>"}]}], 
   RowBox[{",", " ", 
    RowBox[{"OperatorType", "\[Rule]", "\<\"None\"\>"}]}], " ", "]"}],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.5029467886821003`*^9, 3.502946803918304*^9}, 
   3.515083910940297*^9, 3.56890251605529*^9, 3.7121606180037727`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["spin-1/2 pairs", "Section",
 CellChangeTimes->{{3.435164762785845*^9, 3.435164768887135*^9}, {
  3.502946734466859*^9, 3.502946742555179*^9}, {3.5029468352266283`*^9, 
  3.502946839617322*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.502946700828945*^9, 3.502946705267305*^9}, 
   3.502946842122683*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\"",2,14,7,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.502946842458373*^9, 3.515083910982926*^9, 
   3.5689025163213053`*^9, 3.712160618021288*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"BasisLabels\\\", \\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \
\\\"]\\\"}]\\).\"",2,14,8,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.502946842458373*^9, 3.515083910982926*^9, 
   3.5689025163213053`*^9, 3.7121606180423*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.4098391240722437`*^9, 3.430625834584798*^9, 3.4306259637541933`*^9, 
   3.433526846328837*^9, 3.434352338245452*^9, 3.4343534334974117`*^9, 
   3.434353654764881*^9, 3.435164192975973*^9, {3.435164384310895*^9, 
   3.435164398581028*^9}, 3.435164535042913*^9, 3.43516477717758*^9, 
   3.435215747675273*^9, 3.438941567505869*^9, 3.4395535943058243`*^9, {
   3.448348268810351*^9, 3.448348272961355*^9}, 3.448350444269628*^9, 
   3.448350740645598*^9, 3.448362897212866*^9, 3.449299213273988*^9, 
   3.450336458518717*^9, 3.456163219839057*^9, 3.461037069719376*^9, 
   3.461064824085437*^9, 3.4610649590948963`*^9, 3.462799036421393*^9, {
   3.502946678974873*^9, 3.502946708625627*^9}, 3.502946844883263*^9, 
   3.515083911150777*^9, 3.56890251657732*^9, 3.712160618069317*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946849452293*^9, 3.5029468503465643`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    TagBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox["I", "1", "-"],
       DisplayForm], 
      AdjustmentBox["\[Bullet]",
       BoxMargins->{{-0.3, 0}, {0, 0}}], 
      TagBox[
       SubsuperscriptBox["I", "2", "+"],
       DisplayForm]}],
     DisplayForm], "+", 
    TagBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox["I", "1", "+"],
       DisplayForm], 
      AdjustmentBox["\[Bullet]",
       BoxMargins->{{-0.3, 0}, {0, 0}}], 
      TagBox[
       SubsuperscriptBox["I", "2", "-"],
       DisplayForm]}],
     DisplayForm], "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      TagBox[
       RowBox[{
        TagBox[
         SubscriptBox["I", 
          RowBox[{"1", "z"}]],
         DisplayForm], 
        AdjustmentBox["\[Bullet]",
         BoxMargins->{{-0.3, 0}, {0, 0}}], 
        TagBox[
         SubscriptBox["I", 
          RowBox[{"2", "z"}]],
         DisplayForm]}],
       DisplayForm], ")"}]}]}], 
   RowBox[{"2", " ", 
    SqrtBox["6"]}]]}]], "Output",
 CellChangeTimes->{
  3.409839125650468*^9, 3.430625834863289*^9, 3.430625963801936*^9, 
   3.433526846612516*^9, 3.434352338509614*^9, 3.434353433810924*^9, 
   3.434353655084776*^9, 3.435164193242364*^9, {3.4351643843691587`*^9, 
   3.435164398630395*^9}, 3.435164535310061*^9, 3.435164777224841*^9, 
   3.435215747947064*^9, 3.4389415677769957`*^9, 3.439553594593837*^9, {
   3.44834826899916*^9, 3.448348273062286*^9}, 3.4483504443271217`*^9, 
   3.448350740719461*^9, 3.448362897265768*^9, 3.4492992133239202`*^9, 
   3.450336458586773*^9, 3.456163219891069*^9, 3.461037069780645*^9, 
   3.4610648241465054`*^9, 3.461064959143571*^9, 3.462799036503488*^9, 
   3.502946679057289*^9, 3.502946710653652*^9, 3.5029468509508*^9, 
   3.515083911200528*^9, 3.568902516646324*^9, 3.7121606181293592`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946715304886*^9, 3.5029467199394503`*^9}, {
  3.502946857667938*^9, 3.5029468585464163`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      TagBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox["I", "1", "+"],
         DisplayForm], 
        AdjustmentBox["\[Bullet]",
         BoxMargins->{{-0.3, 0}, {0, 0}}], 
        TagBox[
         SubscriptBox["I", 
          RowBox[{"2", "z"}]],
         DisplayForm]}],
       DisplayForm], ")"}]}], "+", 
    TagBox[
     RowBox[{
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "z"}]],
       DisplayForm], 
      AdjustmentBox["\[Bullet]",
       BoxMargins->{{-0.3, 0}, {0, 0}}], 
      TagBox[
       SubsuperscriptBox["I", "2", "+"],
       DisplayForm]}],
     DisplayForm]}], ")"}]}]], "Output",
 CellChangeTimes->{3.502946720395687*^9, 3.502946859115336*^9, 
  3.515083911251409*^9, 3.568902516691326*^9, 3.7121606181658897`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5029467237761307`*^9, 3.5029467280933*^9}, {
  3.50294686207635*^9, 3.5029468662344923`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   TagBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox["I", "1", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "2", "+"],
      DisplayForm]}],
    DisplayForm], ")"}]}]], "Output",
 CellChangeTimes->{3.502946728498217*^9, 3.502946866814332*^9, 
  3.515083911302373*^9, 3.5689025167353287`*^9, 3.7121606181974497`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3 spins-1/2", "Section",
 CellChangeTimes->{{3.435164762785845*^9, 3.435164768887135*^9}, {
  3.502946734466859*^9, 3.502946742555179*^9}, {3.5029468352266283`*^9, 
  3.502946839617322*^9}, {3.5029468793468122`*^9, 3.502946882769053*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.502946700828945*^9, 3.502946705267305*^9}, 
   3.502946842122683*^9, 3.502946885354518*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetSpinSystem","set",
   "\"the spin system has been set to \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \
\\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}]\\)\
\"",2,19,9,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.502946842458373*^9, 3.502946889317998*^9, 
   3.515083911368998*^9, 3.5689025170063443`*^9, 3.712160618211918*^9}],

Cell[BoxData[
 TemplateBox[{
  "SetBasis","set",
   "\"the state basis has been set to \\!\\(\\*RowBox[{\\\"ZeemanBasis\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{\\\"1\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\\\"]}], \
\\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
FractionBox[\\\"1\\\", \\\"2\\\"]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"3\\\", \\\",\\\", FractionBox[\\\"1\\\", \\\"2\
\\\"]}], \\\"}\\\"}]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"BasisLabels\\\", \
\\\"\[Rule]\\\", \\\"Automatic\\\"}]}], \\\"]\\\"}]\\).\"",2,19,10,
   29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.448362897130376*^9, 3.449299213189521*^9, 3.450336458439535*^9, 
   3.456163219772752*^9, 3.461037069669949*^9, 3.461064823246765*^9, 
   3.461064958231711*^9, 3.462799036373358*^9, {3.502946678825768*^9, 
   3.502946705963684*^9}, 3.502946842458373*^9, 3.502946889317998*^9, 
   3.515083911368998*^9, 3.5689025170063443`*^9, 3.712160618232933*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.4098391240722437`*^9, 3.430625834584798*^9, 3.4306259637541933`*^9, 
   3.433526846328837*^9, 3.434352338245452*^9, 3.4343534334974117`*^9, 
   3.434353654764881*^9, 3.435164192975973*^9, {3.435164384310895*^9, 
   3.435164398581028*^9}, 3.435164535042913*^9, 3.43516477717758*^9, 
   3.435215747675273*^9, 3.438941567505869*^9, 3.4395535943058243`*^9, {
   3.448348268810351*^9, 3.448348272961355*^9}, 3.448350444269628*^9, 
   3.448350740645598*^9, 3.448362897212866*^9, 3.449299213273988*^9, 
   3.450336458518717*^9, 3.456163219839057*^9, 3.461037069719376*^9, 
   3.461064824085437*^9, 3.4610649590948963`*^9, 3.462799036421393*^9, {
   3.502946678974873*^9, 3.502946708625627*^9}, 3.502946844883263*^9, 
   3.502946889384054*^9, 3.5150839114523706`*^9, 3.5689025172743597`*^9, 
   3.7121606183355074`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946849452293*^9, 3.5029468503465643`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    TagBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox["I", "1", "-"],
       DisplayForm], 
      AdjustmentBox["\[Bullet]",
       BoxMargins->{{-0.3, 0}, {0, 0}}], 
      TagBox[
       SubsuperscriptBox["I", "2", "+"],
       DisplayForm]}],
     DisplayForm], "+", 
    TagBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox["I", "1", "+"],
       DisplayForm], 
      AdjustmentBox["\[Bullet]",
       BoxMargins->{{-0.3, 0}, {0, 0}}], 
      TagBox[
       SubsuperscriptBox["I", "2", "-"],
       DisplayForm]}],
     DisplayForm], "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      TagBox[
       RowBox[{
        TagBox[
         SubscriptBox["I", 
          RowBox[{"1", "z"}]],
         DisplayForm], 
        AdjustmentBox["\[Bullet]",
         BoxMargins->{{-0.3, 0}, {0, 0}}], 
        TagBox[
         SubscriptBox["I", 
          RowBox[{"2", "z"}]],
         DisplayForm]}],
       DisplayForm], ")"}]}]}], 
   RowBox[{"2", " ", 
    SqrtBox["6"]}]]}]], "Output",
 CellChangeTimes->{
  3.409839125650468*^9, 3.430625834863289*^9, 3.430625963801936*^9, 
   3.433526846612516*^9, 3.434352338509614*^9, 3.434353433810924*^9, 
   3.434353655084776*^9, 3.435164193242364*^9, {3.4351643843691587`*^9, 
   3.435164398630395*^9}, 3.435164535310061*^9, 3.435164777224841*^9, 
   3.435215747947064*^9, 3.4389415677769957`*^9, 3.439553594593837*^9, {
   3.44834826899916*^9, 3.448348273062286*^9}, 3.4483504443271217`*^9, 
   3.448350740719461*^9, 3.448362897265768*^9, 3.4492992133239202`*^9, 
   3.450336458586773*^9, 3.456163219891069*^9, 3.461037069780645*^9, 
   3.4610648241465054`*^9, 3.461064959143571*^9, 3.462799036503488*^9, 
   3.502946679057289*^9, 3.502946710653652*^9, 3.5029468509508*^9, 
   3.5029468894186687`*^9, 3.515083911501604*^9, 3.5689025173263626`*^9, 
   3.7121606183716106`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946715304886*^9, 3.5029467199394503`*^9}, {
  3.502946857667938*^9, 3.5029468585464163`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      TagBox[
       RowBox[{
        TagBox[
         SubsuperscriptBox["I", "1", "+"],
         DisplayForm], 
        AdjustmentBox["\[Bullet]",
         BoxMargins->{{-0.3, 0}, {0, 0}}], 
        TagBox[
         SubscriptBox["I", 
          RowBox[{"2", "z"}]],
         DisplayForm]}],
       DisplayForm], ")"}]}], "+", 
    TagBox[
     RowBox[{
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "z"}]],
       DisplayForm], 
      AdjustmentBox["\[Bullet]",
       BoxMargins->{{-0.3, 0}, {0, 0}}], 
      TagBox[
       SubsuperscriptBox["I", "2", "+"],
       DisplayForm]}],
     DisplayForm]}], ")"}]}]], "Output",
 CellChangeTimes->{3.502946720395687*^9, 3.502946859115336*^9, 
  3.502946889454754*^9, 3.515083911553178*^9, 3.5689025173803663`*^9, 
  3.7121606184161854`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5029467237761307`*^9, 3.5029467280933*^9}, {
  3.50294686207635*^9, 3.5029468662344923`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   TagBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox["I", "1", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "2", "+"],
      DisplayForm]}],
    DisplayForm], ")"}]}]], "Output",
 CellChangeTimes->{
  3.502946728498217*^9, {3.502946866814332*^9, 3.502946889486931*^9}, 
   3.515083911600504*^9, 3.5689025174283686`*^9, 3.712160618451165*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946897084086*^9, 3.502946903202457*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   TagBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox["I", "1", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "2", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "3", "+"],
      DisplayForm]}],
    DisplayForm], 
   RowBox[{"2", " ", 
    SqrtBox["2"]}]]}]], "Output",
 CellChangeTimes->{{3.5029468979058228`*^9, 3.502946903546726*^9}, 
   3.515083911657874*^9, 3.5689025175183735`*^9, 3.7121606185162115`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946897084086*^9, 3.502946909740279*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   TagBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox["I", "1", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "2", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubscriptBox["I", 
       RowBox[{"3", "z"}]],
      DisplayForm]}],
    DisplayForm], "+", 
   TagBox[
    RowBox[{
     TagBox[
      SubsuperscriptBox["I", "1", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubscriptBox["I", 
       RowBox[{"2", "z"}]],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "3", "+"],
      DisplayForm]}],
    DisplayForm], "+", 
   TagBox[
    RowBox[{
     TagBox[
      SubscriptBox["I", 
       RowBox[{"1", "z"}]],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "2", "+"],
      DisplayForm], 
     AdjustmentBox["\[Bullet]",
      BoxMargins->{{-0.3, 0}, {0, 0}}], 
     TagBox[
      SubsuperscriptBox["I", "3", "+"],
      DisplayForm]}],
    DisplayForm]}], 
  RowBox[{"2", " ", 
   SqrtBox["3"]}]]], "Output",
 CellChangeTimes->{{3.5029468979058228`*^9, 3.502946910058906*^9}, 
   3.515083911715184*^9, 3.568902517598378*^9, 3.7121606185852604`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.502946897084086*^9, 3.502946916124452*^9}}],

Cell[BoxData[
 TemplateBox[{
  "opT","multiple",
   "\"There are \\!\\(\\*RowBox[{\\\"2\\\"}]\\) operators with this \
specification. A list of all possibilities has been returned. Specify a \
single operator using the form opT[interactions,{Lam,M},index] where index is \
an integer.\"",2,26,11,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.5029469170762453`*^9, 3.515083911809124*^9, 
  3.568902517835392*^9, 3.7121606185997715`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       TagBox[
        SubsuperscriptBox["I", "1", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm], "-", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "2", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       TagBox[
        RowBox[{
         TagBox[
          SubsuperscriptBox["I", "1", "+"],
          DisplayForm], 
         AdjustmentBox["\[Bullet]",
          BoxMargins->{{-0.3, 0}, {0, 0}}], 
         TagBox[
          SubsuperscriptBox["I", "2", "+"],
          DisplayForm], 
         AdjustmentBox["\[Bullet]",
          BoxMargins->{{-0.3, 0}, {0, 0}}], 
         TagBox[
          SubscriptBox["I", 
           RowBox[{"3", "z"}]],
          DisplayForm]}],
        DisplayForm], ")"}]}], "-", 
     TagBox[
      RowBox[{
       TagBox[
        SubsuperscriptBox["I", "1", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm], "-", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "2", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm]}], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.5029468979058228`*^9, 3.502946917115016*^9}, 
   3.515083911847837*^9, 3.568902517908396*^9, 3.712160618703344*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.502946897084086*^9, 3.502946927290245*^9}}],

Cell[BoxData[
 TemplateBox[{
  "opT","multiple",
   "\"There are \\!\\(\\*RowBox[{\\\"2\\\"}]\\) operators with this \
specification. A list of all possibilities has been returned. Specify a \
single operator using the form opT[interactions,{Lam,M},index] where index is \
an integer.\"",2,27,12,29119468785498852949,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7121606187178555`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     TagBox[
      RowBox[{
       TagBox[
        SubsuperscriptBox["I", "1", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm], "-", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "2", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       TagBox[
        RowBox[{
         TagBox[
          SubsuperscriptBox["I", "1", "+"],
          DisplayForm], 
         AdjustmentBox["\[Bullet]",
          BoxMargins->{{-0.3, 0}, {0, 0}}], 
         TagBox[
          SubsuperscriptBox["I", "2", "+"],
          DisplayForm], 
         AdjustmentBox["\[Bullet]",
          BoxMargins->{{-0.3, 0}, {0, 0}}], 
         TagBox[
          SubscriptBox["I", 
           RowBox[{"3", "z"}]],
          DisplayForm]}],
        DisplayForm], ")"}]}], "-", 
     TagBox[
      RowBox[{
       TagBox[
        SubsuperscriptBox["I", "1", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubscriptBox["I", 
         RowBox[{"2", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm], "-", 
     TagBox[
      RowBox[{
       TagBox[
        SubscriptBox["I", 
         RowBox[{"1", "z"}]],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "2", "+"],
        DisplayForm], 
       AdjustmentBox["\[Bullet]",
        BoxMargins->{{-0.3, 0}, {0, 0}}], 
       TagBox[
        SubsuperscriptBox["I", "3", "+"],
        DisplayForm]}],
      DisplayForm]}], 
    RowBox[{"2", " ", 
     SqrtBox["6"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.5029468979058228`*^9, 3.5029469278898983`*^9}, 
   3.515083911903409*^9, 3.5689025179673996`*^9, 3.712160618797411*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opT", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.502946897084086*^9, 3.502946934172185*^9}}],

Cell[BoxData[
 TemplateBox[{
  "opT","fail","\"failure in opT routine\"",2,28,13,29119468785498852949,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7121606188109202`*^9}],

Cell[BoxData["\<\"\[DoubleStruckCapitalO]\"\>"], "Output",
 CellChangeTimes->{{3.5029468979058228`*^9, 3.5029469348512297`*^9}, 
   3.515083911970956*^9, 3.568902518027403*^9, 3.7121606188339367`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"mhl-default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info23712164217-9518567"->{
  Cell[2117, 63, 1779, 26, 223, "Print",
   CellTags->"Info23712164217-9518567"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info23712164217-9518567", 42385, 1299}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 194, 3, 30, "Input"],
Cell[764, 27, 147, 4, 36, "Print"],
Cell[914, 33, 838, 15, 40, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1789, 53, 189, 2, 63, "Section"],
Cell[CellGroupData[{
Cell[2003, 59, 111, 2, 30, "Input"],
Cell[2117, 63, 1779, 26, 223, "Print",
 CellTags->"Info23712164217-9518567"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3945, 95, 149, 2, 63, "Section"],
Cell[CellGroupData[{
Cell[4119, 101, 132, 2, 30, "Input"],
Cell[4254, 105, 649, 12, 47, "Message"],
Cell[4906, 119, 791, 15, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5734, 139, 128, 4, 30, "Input"],
Cell[5865, 145, 877, 16, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6779, 166, 128, 4, 30, "Input"],
Cell[6910, 172, 844, 12, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7791, 189, 196, 5, 30, "Input"],
Cell[7990, 196, 255, 8, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8282, 209, 215, 6, 30, "Input"],
Cell[8500, 217, 233, 7, 60, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8782, 230, 149, 2, 63, "Section"],
Cell[CellGroupData[{
Cell[8956, 236, 279, 7, 30, "Input"],
Cell[9238, 245, 667, 12, 47, "Message"],
Cell[9908, 259, 813, 15, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10758, 279, 128, 4, 30, "Input"],
Cell[10889, 285, 900, 16, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11826, 306, 128, 4, 30, "Input"],
Cell[11957, 312, 1902, 58, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13896, 375, 194, 5, 30, "Input"],
Cell[14093, 382, 469, 16, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14599, 403, 194, 5, 30, "Input"],
Cell[14796, 410, 415, 8, 21, "Message"],
Cell[15214, 420, 353, 10, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15604, 435, 194, 5, 30, "Input"],
Cell[15801, 442, 372, 10, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16222, 458, 199, 3, 63, "Section"],
Cell[CellGroupData[{
Cell[16446, 465, 158, 3, 30, "Input"],
Cell[16607, 470, 794, 14, 47, "Message"],
Cell[17404, 486, 933, 16, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18374, 507, 128, 4, 30, "Input"],
Cell[18505, 513, 897, 16, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19439, 534, 245, 7, 30, "Input"],
Cell[19687, 543, 1858, 54, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21582, 602, 296, 8, 30, "Input"],
Cell[21881, 612, 893, 32, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22811, 649, 293, 8, 30, "Input"],
Cell[23107, 659, 491, 16, 53, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23647, 681, 244, 3, 63, "Section"],
Cell[CellGroupData[{
Cell[23916, 688, 180, 3, 30, "Input"],
Cell[24099, 693, 930, 16, 47, "Message"],
Cell[25032, 711, 1074, 18, 47, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26143, 734, 128, 4, 30, "Input"],
Cell[26274, 740, 930, 17, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27241, 762, 245, 7, 30, "Input"],
Cell[27489, 771, 1888, 55, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29414, 831, 296, 8, 30, "Input"],
Cell[29713, 841, 920, 33, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30670, 879, 293, 8, 30, "Input"],
Cell[30966, 889, 517, 17, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31520, 911, 253, 7, 30, "Input"],
Cell[31776, 920, 653, 22, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32466, 947, 253, 7, 30, "Input"],
Cell[32722, 956, 1517, 57, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34276, 1018, 253, 7, 30, "Input"],
Cell[34532, 1027, 482, 9, 23, "Message"],
Cell[35017, 1038, 2752, 99, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37806, 1142, 263, 7, 30, "Input"],
Cell[38072, 1151, 411, 8, 23, "Message"],
Cell[38486, 1161, 2756, 99, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41279, 1265, 263, 7, 30, "Input"],
Cell[41545, 1274, 200, 5, 21, "Message"],
Cell[41748, 1281, 200, 2, 63, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

